@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,9 +30,9 @@ class PIMCOMMON_EXPORT RichTextEditWithAutoCorrection : public KPIMTextEdit::Ric
     Q_OBJECT
 public:
     explicit RichTextEditWithAutoCorrection(QWidget *parent = nullptr);
-    ~RichTextEditWithAutoCorrection();
+    ~RichTextEditWithAutoCorrection() override;
 
-    PimCommon::AutoCorrection *autocorrection() const;
+    Q_REQUIRED_RESULT PimCommon::AutoCorrection *autocorrection() const;
 
     void setAutocorrection(PimCommon::AutoCorrection *autocorrect);
 
